@@ -1,6 +1,7 @@
 use 5.036;
 
 use Slick;
+use Slick::Annotation qw(cacheable);
 
 my $s = Slick->new;
 
@@ -20,6 +21,7 @@ $s->cache(
 
 $s->cache('my_redis')->set( something => 'awesome' );
 
+# Use your cache
 $s->get(
     '/foo' => sub {
         my ( $app, $context ) = @_;
@@ -28,4 +30,15 @@ $s->get(
     }
 );
 
+# Use your cache to cache your route
+$s->get(
+    '/foobar' => cacheable(
+        'my_redis',
+        sub {
+            my ( $app, $context ) = @_;
+            return $context->json( { foo => 'bar' } );
+        }
+    )
+);
+
 $s->run;
